"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeHttpApi = void 0;
var makeHttpApi = function (_a) {
    var name = _a.name, stage = _a.stage, auth = _a.auth;
    var template = {
        Resources: {
            ApiRoot: {
                Type: 'AWS::ApiGatewayV2::Api',
                Properties: {
                    Name: "".concat(name, "-").concat(stage),
                    ProtocolType: 'HTTP'
                }
            },
            ApiStage: {
                Type: 'AWS::ApiGatewayV2::Stage',
                Properties: {
                    ApiId: {
                        Ref: 'ApiRoot'
                    },
                    StageName: '$default',
                    AutoDeploy: true,
                    DefaultRouteSettings: {
                        DetailedMetricsEnabled: true
                    }
                }
            }
        },
        Outputs: {
            ApiUrl: {
                Description: 'URL',
                Value: {
                    'Fn::Join': [
                        '',
                        [
                            'https://',
                            {
                                Ref: 'ApiRoot'
                            },
                            '.execute-api.',
                            {
                                Ref: 'AWS::Region'
                            },
                            '.',
                            {
                                Ref: 'AWS::URLSuffix'
                            }
                        ]
                    ]
                }
            }
        }
    };
    if (auth) {
        var cognitoAuthorizer = {
            ApiAuthorizer: {
                Type: 'AWS::ApiGatewayV2::Authorizer',
                Properties: {
                    ApiId: {
                        Ref: 'ApiRoot'
                    },
                    Name: 'JwtAuthorizer',
                    IdentitySource: ['$request.header.Authorization'],
                    AuthorizerType: 'JWT',
                    JwtConfiguration: {
                        Audience: [
                            {
                                Ref: auth.clientIdRef
                            }
                        ],
                        Issuer: {
                            'Fn::Sub': "https://cognito-idp.${AWS::Region}.amazonaws.com/${".concat(auth.poolIdRef, "}")
                        }
                    }
                }
            }
        };
        template.Resources = __assign(__assign({}, template.Resources), cognitoAuthorizer);
    }
    return template;
};
exports.makeHttpApi = makeHttpApi;
