"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeHttpApiRoute = void 0;
var makeHttpApiRoute = function (_a) {
    var _b;
    var route = _a.route, method = _a.method, functionReference = _a.functionReference, authorizerRef = _a.authorizerRef;
    var permissiionKey = "".concat(functionReference, "PermissionHttp");
    var integrationKey = "HttpApiIntegration".concat(functionReference);
    var routeKey = "HttpApi".concat(route).concat(method).concat(functionReference);
    var template = {
        Resources: (_b = {},
            _b[permissiionKey] = {
                Type: 'AWS::Lambda::Permission',
                Properties: {
                    FunctionName: {
                        'Fn::GetAtt': [functionReference, 'Arn']
                    },
                    Action: 'lambda:InvokeFunction',
                    Principal: 'apigateway.amazonaws.com',
                    SourceArn: {
                        'Fn::Sub': "arn:aws:execute-api:${AWS::Region}:${AWS::AccountId}:${ApiRoot}/*"
                    }
                }
            },
            _b[integrationKey] = {
                Type: 'AWS::ApiGatewayV2::Integration',
                Properties: {
                    ApiId: {
                        Ref: 'ApiRoot'
                    },
                    IntegrationType: 'AWS_PROXY',
                    IntegrationUri: {
                        'Fn::GetAtt': [functionReference, 'Arn']
                    },
                    PayloadFormatVersion: '2.0',
                    TimeoutInMillis: 6500
                }
            },
            _b[routeKey] = {
                Type: 'AWS::ApiGatewayV2::Route',
                Properties: {
                    ApiId: {
                        Ref: 'ApiRoot'
                    },
                    RouteKey: "".concat(method, " /").concat(route),
                    Target: {
                        'Fn::Join': [
                            '/',
                            [
                                'integrations',
                                {
                                    Ref: integrationKey
                                }
                            ]
                        ]
                    }
                },
                DependsOn: [integrationKey]
            },
            _b),
        Outputs: {}
    };
    if (authorizerRef) {
        var routeAuthConfig = {
            AuthorizationType: 'JWT',
            AuthorizerId: {
                Ref: authorizerRef
            },
            AuthorizationScopes: ['user.id', 'user.email']
        };
        template.Resources[routeKey].DependsOn.push('ApiAuthorizer');
        template.Resources[routeKey].Properties = __assign(__assign({}, template.Resources[routeKey].Properties), routeAuthConfig);
    }
    return template;
};
exports.makeHttpApiRoute = makeHttpApiRoute;
