"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.makeDashboard = void 0;
var getPosition = function (h, v) {
    return {
        x: h * 6,
        y: v * 6
    };
};
var makeAnnotations = function (goal, alarm) {
    var annotations = [];
    if (goal !== undefined) {
        annotations.push({
            color: '#2ca02c',
            label: 'Goal',
            value: goal
        });
    }
    if (alarm !== undefined) {
        annotations.push({
            color: '#d62728',
            label: 'Alarm',
            value: alarm
        });
    }
    return annotations;
};
var makeDocBlock = function (config) { return ({
    type: 'text',
    x: 0,
    y: getPosition(config.h, 0).y,
    width: 6,
    height: 6,
    properties: {
        markdown: config.content
    }
}); };
var makeLambdaTrafficBlock = function (config) {
    return {
        type: 'metric',
        x: 6,
        y: getPosition(config.h, 0).y,
        width: 6,
        height: 6,
        properties: {
            metrics: [
                [
                    'AWS/Lambda',
                    'Invocations',
                    'FunctionName',
                    config.functionName
                ]
            ],
            view: 'timeSeries',
            stacked: false,
            region: config.region,
            period: 300,
            annotations: {
                horizontal: makeAnnotations(config.goal, config.alarm)
            },
            stat: 'Sum',
            title: 'Traffic'
        }
    };
};
var makeLambdaErrorBlock = function (config) {
    return {
        type: 'metric',
        x: 12,
        y: getPosition(config.h, 0).y,
        width: 6,
        height: 6,
        properties: {
            metrics: [
                ['AWS/Lambda', 'Errors', 'FunctionName', config.functionName]
            ],
            view: 'timeSeries',
            stacked: false,
            region: config.region,
            period: 300,
            annotations: {
                horizontal: makeAnnotations(config.goal, config.alarm)
            },
            stat: 'Sum',
            title: 'Availability (Errors)'
        }
    };
};
var makeLambdaDurationBlock = function (config) {
    return {
        type: 'metric',
        x: 18,
        y: getPosition(config.h, 0).y,
        width: 6,
        height: 6,
        properties: {
            metrics: [
                ['AWS/Lambda', 'Duration', 'FunctionName', config.functionName]
            ],
            view: 'timeSeries',
            stacked: false,
            region: config.region,
            period: 300,
            annotations: {
                horizontal: makeAnnotations(config.goal, config.alarm)
            },
            stat: 'p99',
            title: 'Latency (duration)'
        }
    };
};
var makeLambdaRow = function (row) {
    return [
        makeDocBlock({
            h: row.verticalPosition,
            content: row.docs || ''
        }),
        makeLambdaTrafficBlock({
            h: row.verticalPosition,
            functionName: row.functionName,
            region: row.region,
            goal: row.invocationGoal,
            alarm: row.invocationAlarm
        }),
        makeLambdaErrorBlock({
            h: row.verticalPosition,
            functionName: row.functionName,
            region: row.region,
            goal: row.errorGoal,
            alarm: row.errorAlarm
        }),
        makeLambdaDurationBlock({
            h: row.verticalPosition,
            functionName: row.functionName,
            region: row.region,
            goal: row.durationGoal,
            alarm: row.durationAlarm
        })
    ];
};
function makeDashboard(config) {
    var _a;
    var widgets = [];
    config.rows.forEach(function (x) {
        if (x.type === 'LAMBDAROW') {
            makeLambdaRow(x).forEach(function (x) { return widgets.push(x); });
        }
    });
    return {
        Resources: (_a = {},
            _a[config.name + 'Dashboard'] = {
                Type: 'AWS::CloudWatch::Dashboard',
                Properties: {
                    DashboardName: config.name,
                    DashboardBody: JSON.stringify({ widgets: widgets })
                }
            },
            _a),
        Outputs: {}
    };
}
exports.makeDashboard = makeDashboard;
