import { deployStack } from './cloudformation/deployStack';
import { getDeployStatus } from './cloudformation/getDeployStatus';
import { getOutputs } from './cloudformation/getOutputs';
import { removeStack } from './cloudformation/removeStack';
import { makeInlineLambda } from './lambda/makeInlineLambda';
import { makeLambda } from './lambda/makeLambda';
import { updateLambdaCode } from './lambda/updateLambdaCode';
import makeSimpleBucket from './s3/makeSimpleBucket';
import makeBucket from './s3/makeBucket';
import getFile from './s3/getFile';
import getFileUrl from './s3/getFileUrl';
import removeFile from './s3/removeFile';
import { uploadFile } from './s3/uploadFile';
import { makeEventRule } from './eventBridge/makeEventRule';
import { makeArtifactBucket } from './codestar/cf/makeArtifactBucket';
import { makeGithubConnection } from './codestar/cf/makeGithubConnection';
import { makeBuildProject } from './codestar/cf/makeBuildProject';
import { makePipeline } from './codestar/cf/makePipeline';
import { getKeyword } from './keywords/index';
import { makeDashboard } from './cloudwatch/makeDashboard';
import { makeLambdaErrorAlarm } from './cloudwatch/makeLambdaErrorAlarm';
declare const _default: {
    cloudformation: {
        deployStack: typeof deployStack;
        getDeployStatus: typeof getDeployStatus;
        getOutputs: typeof getOutputs;
        removeStack: typeof removeStack;
    };
    lambda: {
        makeInlineLambda: typeof makeInlineLambda;
        makeLambda: typeof makeLambda;
        updateLambdaCode: typeof updateLambdaCode;
        invokeLambda: ({ name, payload, region }: {
            name: string;
            payload: any;
            region?: string | undefined;
        }) => Promise<any>;
    };
    s3: {
        makeBucket: typeof makeBucket;
        makeSimpleBucket: typeof makeSimpleBucket;
        getFile: typeof getFile;
        getFileUrl: typeof getFileUrl;
        removeFile: typeof removeFile;
        uploadFile: typeof uploadFile;
    };
    apigateway: {
        makeHttpApi: ({ name, stage, auth }: {
            name: string;
            stage: string;
            auth?: {
                poolIdRef: string;
                clientIdRef: string;
            } | undefined;
        }) => {
            Resources: {
                ApiRoot: {
                    Type: string;
                    Properties: {
                        Name: string;
                        ProtocolType: string;
                    };
                };
                ApiStage: {
                    Type: string;
                    Properties: {
                        ApiId: {
                            Ref: string;
                        };
                        StageName: string;
                        AutoDeploy: boolean;
                        DefaultRouteSettings: {
                            DetailedMetricsEnabled: boolean;
                        };
                    };
                };
            };
            Outputs: {
                ApiUrl: {
                    Description: string;
                    Value: {
                        'Fn::Join': (string | (string | {
                            Ref: string;
                        })[])[];
                    };
                };
            };
        };
        makeHttpApiRoute: ({ route, method, functionReference, authorizerRef }: {
            route: string;
            method: string;
            functionReference: string;
            authorizerRef?: string | undefined;
        }) => {
            Resources: {
                [x: string]: {
                    Type: string;
                    Properties: {
                        FunctionName: {
                            'Fn::GetAtt': string[];
                        };
                        Action: string;
                        Principal: string;
                        SourceArn: {
                            'Fn::Sub': string;
                        };
                        ApiId?: undefined;
                        IntegrationType?: undefined;
                        IntegrationUri?: undefined;
                        PayloadFormatVersion?: undefined;
                        TimeoutInMillis?: undefined;
                        RouteKey?: undefined;
                        Target?: undefined;
                    };
                    DependsOn?: undefined;
                } | {
                    Type: string;
                    Properties: {
                        ApiId: {
                            Ref: string;
                        };
                        IntegrationType: string;
                        IntegrationUri: {
                            'Fn::GetAtt': string[];
                        };
                        PayloadFormatVersion: string;
                        TimeoutInMillis: number;
                        FunctionName?: undefined;
                        Action?: undefined;
                        Principal?: undefined;
                        SourceArn?: undefined;
                        RouteKey?: undefined;
                        Target?: undefined;
                    };
                    DependsOn?: undefined;
                } | {
                    Type: string;
                    Properties: {
                        ApiId: {
                            Ref: string;
                        };
                        RouteKey: string;
                        Target: {
                            'Fn::Join': (string | (string | {
                                Ref: string;
                            })[])[];
                        };
                        FunctionName?: undefined;
                        Action?: undefined;
                        Principal?: undefined;
                        SourceArn?: undefined;
                        IntegrationType?: undefined;
                        IntegrationUri?: undefined;
                        PayloadFormatVersion?: undefined;
                        TimeoutInMillis?: undefined;
                    };
                    DependsOn: string[];
                };
            };
            Outputs: {};
        };
    };
    eventBridge: {
        makeEventRule: typeof makeEventRule;
    };
    cognito: {
        makeCognito: (appName: string, stage: string) => {
            Resources: {
                CognitoUserPool: {
                    Type: string;
                    Properties: {
                        UserPoolName: string;
                        AdminCreateUserConfig: {
                            AllowAdminCreateUserOnly: boolean;
                            UnusedAccountValidityDays: number;
                        };
                    };
                };
                CognitoUserPoolClient: {
                    Type: string;
                    Properties: {
                        ClientName: string;
                        UserPoolId: {
                            Ref: string;
                        };
                        ExplicitAuthFlows: string[];
                        GenerateSecret: boolean;
                    };
                };
            };
            Outputs: {
                UserPoolId: {
                    Value: {
                        Ref: string;
                    };
                };
                UserPoolClientId: {
                    Value: {
                        Ref: string;
                    };
                };
            };
        };
    };
    codestar: {
        makeArtifactBucket: typeof makeArtifactBucket;
        makeGithubConnection: typeof makeGithubConnection;
        makeBuildProject: typeof makeBuildProject;
        makePipeline: typeof makePipeline;
    };
    keywords: {
        getKeyword: typeof getKeyword;
    };
    cloudwatch: {
        makeDashboard: typeof makeDashboard;
        makeLambdaErrorAlarm: typeof makeLambdaErrorAlarm;
    };
};
export default _default;
